==> nextcloud-25.0.12p1.tgz: nextcloud/apps/activity/l10n/zh_CN.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
    "{name} (invisible)" : "{name} (不可见)",
    "{name} (restricted)" : "{name} (受限的)",
    "Home" : "主页",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "流中会显示诸如添加、更改和共享之类的事件",
    "There are no events for this filter" : "没有符合当前筛选条件的事件。",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "Open {filename}" : "打开 {filename}",
    "Activity" : "动态",
    "Personal activity feed for %s" : "%s 的个人活动订阅源",
    "Your feed URL is invalid" : "您的订阅源地址无效",
    "Your settings have been updated." : "您的设置已更新。",
    "Settings have been updated." : "设置已更新。",
    "Recent activity" : "最近动态",
    "No activities" : "无活动",
    "More activities" : "更多活动",
    "Daily activity summary for %s" : "%s 的每日动态概况",
    "_and %n more _::_and %n more _" : ["更多 %n 项"],
    "All activities" : "所有动态",
    "By others" : "其他来源",
    "By you" : "本地来源",
    "Activity at %s" : "%s 的动态",
    "Hello %s" : "%s 您好",
    "Hello %s," : "%s 你好，",
    "There was some activity at %s" : "在 %s 里有一些动态",
    "Mail" : "邮件",
    "Push" : "推送",
    "Notifications" : "通知",
    "This application enables people to view a log of activities about them, their files or other data." : "这个应用使用户可以查看关于自己或文件或其他数据的动态日志。 ",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "此应用允许用户查看与他们在 Nextcloud 中的文档与其他数据相关的操作。\n\t\t每个人都可以在他们的个人设置中设定自己的个人活动记录，\n\t\t选择要推送到手机或通过电子邮件推送的活动\n\t\t或是否每天早上推送每日摘要。\n\t\t可在活动记录文档中查看更多信息。",
    "Activity notification configuration" : "动态通知配置",
    "Send email" : "发送邮件",
    "Send push notification" : "发送推送通知",
    "You need to set up your email address before you can receive notification emails." : "要接收通知邮件，需要先设置您的电子邮件地址。",
    "Send activity emails" : "发送动态电子邮件",
    "As soon as possible" : "尽快",
    "Hourly" : "每小时",
    "Daily" : "每天",
    "Weekly" : "每周",
    "No activity yet" : "暂无动态",
    "Unable to load the activity list" : "无法加载活动列表",
    "Notification" : "通知",
    "Enable notification emails" : "启用邮件通知",
    "Choose for which activities you want to get an email or push notification." : "选择您要为哪些动态接收电子邮件或推送通知。",
    "Choose for which activities you want to get a push notification." : "选择您要为哪些动态接收推送通知。",
    "Daily activity summary" : "每日动态总结",
    "Send daily activity summary in the morning" : "在早上发送每日动态概要",
    "Default settings" : "默认设置",
    "Configure the default notification settings for new accounts." : "为新帐号配置默认通知设置",
    "Unable to save the settings" : "无法保存设置",
    "Activity feed" : "活动订阅源",
    "Activity settings" : "动态设置",
    "Enable RSS feed" : "启用 RSS 订阅源",
    "RSS feed" : "RSS 订阅源",
    "Copy RSS feed link" : "复制 RSS 订阅链接",
    "Personal notification settings" : "个人通知设置",
    "No more events to load" : "已无更多事件",
    "This application enables users to view a log of activities about them or about files." : "这个应用使用户可以查看关于自己或文件的动态日志。 ",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "本应用能够让用户查看与他们在Nextcloud中的文件相关的活动。\n\t\t一旦启用，用户将看到在他们的应用菜单中出现了一个名为”动态“的新图标.\n\t\t点击后会出现一个页面让用户跟踪文件的动态，包括新增文件、删除文件、移动、重命名、修改和共享。\n\t\t用户可以在个人的菜单中指定单独的动态设置。\n\t\t可以设置要记录的活动类型，以及是否用户看到自己的活动、\n\t\t是否只能在线查看、是否定期收到电子邮件摘要。\n\t\t 更多信息可以在动态文档中进行查看。",
    "Activities" : "动态",
    "Configure the default notification settings for new users." : "为新用户配置默认通知设置"
},
"nplurals=1; plural=0;");

==> nextcloud-27.1.4.tgz: nextcloud/apps/activity/l10n/zh_CN.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "%s 的个人活动订阅源",
    "Your feed URL is invalid" : "您的订阅源地址无效",
    "Activity feed for %1$s" : "%1$s 的动态",
    "Activity feed" : "活动订阅源",
    "Your settings have been updated." : "您的设置已更新。",
    "Settings have been updated." : "设置已更新。",
    "Recent activity" : "最近动态",
    "No activities" : "无活动",
    "More activities" : "更多活动",
    "Daily activity summary for %s" : "%s 的每日动态概况",
    "_and %n more _::_and %n more _" : ["更多 %n 项"],
    "All activities" : "所有动态",
    "By others" : "其他来源",
    "By you" : "本地来源",
    "Activity at %s" : "%s 的动态",
    "Hello %s" : "%s 您好",
    "Hello %s," : "%s 你好，",
    "There was some activity at %s" : "在 %s 里有一些动态",
    "Mail" : "邮件",
    "Push" : "推送",
    "Activity" : "动态",
    "Notifications" : "通知",
    "This application enables people to view a log of activities about them, their files or other data." : "这个应用使用户可以查看关于自己或文件或其他数据的动态日志。 ",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "此应用允许用户查看与他们在 Nextcloud 中的文档与其他数据相关的操作。\n\t\t每个人都可以在他们的个人设置中设定自己的个人活动记录，\n\t\t选择要推送到手机或通过电子邮件推送的活动\n\t\t或是否每天早上推送每日摘要。\n\t\t可在活动记录文档中查看更多信息。",
    "Activity notification configuration" : "动态通知配置",
    "Send email" : "发送邮件",
    "Send push notification" : "发送推送通知",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "You need to set up your email address before you can receive notification emails." : "要接收通知邮件，需要先设置您的电子邮件地址。",
    "Send activity emails" : "发送动态电子邮件",
    "As soon as possible" : "尽快",
    "Hourly" : "每小时",
    "Daily" : "每天",
    "Weekly" : "每周",
    "You commented" : "你的评论",
    "Message deleted by author" : "消息被作者删除了",
    "Open {filename}" : "打开 {filename}",
    "in {path}" : "在 {path}",
    "Home" : "主页",
    "Your activities" : "你的动态",
    "Loading activities" : "正在加载动态",
    "This stream will show events like additions, changes & shares" : "流中会显示诸如添加、更改和共享之类的事件",
    "No activity yet" : "暂无动态",
    "Loading more activities" : "正在加载更多动态",
    "No more activities." : "暂无更多动态。",
    "Could not load activites" : "无法加载动态",
    "Activity settings" : "动态设置",
    "Enable RSS feed" : "启用 RSS 订阅源",
    "RSS feed" : "RSS 订阅源",
    "Copy RSS feed link" : "复制 RSS 订阅链接",
    "Personal notification settings" : "个人通知设置",
    "Could not enable RSS link" : "无法激活 RSS 链接",
    "RSS link copied to clipboard" : "RSS 链接已拷贝至剪贴板",
    "Could not copy the RSS link, please copy manually:" : "无法复制 RSS 链接，请手动进行该操作：",
    "Unable to load the activity list" : "无法加载活动列表",
    "Notification" : "通知",
    "Enable notification emails" : "启用邮件通知",
    "Choose for which activities you want to get an email or push notification." : "选择您要为哪些动态接收电子邮件或推送通知。",
    "Choose for which activities you want to get a push notification." : "选择您要为哪些动态接收推送通知。",
    "Daily activity summary" : "每日动态总结",
    "Send daily activity summary in the morning" : "在早上发送每日动态概要",
    "Default settings" : "默认设置",
    "Configure the default notification settings for new accounts." : "为新帐号配置默认通知设置",
    "Unable to save the settings" : "无法保存设置",
    "No more events to load" : "已无更多事件",
    "Copied!" : "已复制！",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "请按 ⌘-C 键复制",
    "Press Ctrl-C to copy." : "请按 Ctrl-C 键复制",
    "{name} (invisible)" : "{name} (不可见)",
    "{name} (restricted)" : "{name} (受限的)",
    "There are no events for this filter" : "没有符合当前筛选条件的事件。",
    "This application enables users to view a log of activities about them or about files." : "这个应用使用户可以查看关于自己或文件的动态日志。 ",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "本应用能够让用户查看与他们在Nextcloud中的文件相关的活动。\n\t\t一旦启用，用户将看到在他们的应用菜单中出现了一个名为”动态“的新图标.\n\t\t点击后会出现一个页面让用户跟踪文件的动态，包括新增文件、删除文件、移动、重命名、修改和共享。\n\t\t用户可以在个人的菜单中指定单独的动态设置。\n\t\t可以设置要记录的活动类型，以及是否用户看到自己的活动、\n\t\t是否只能在线查看、是否定期收到电子邮件摘要。\n\t\t 更多信息可以在动态文档中进行查看。",
    "Activities" : "动态",
    "Configure the default notification settings for new users." : "为新用户配置默认通知设置"
},
"nplurals=1; plural=0;");
